#include <stdio.h>
#include <string.h>
#include <stdint.h>
#include "pci_comms.h"
#include "tsi_struct.h"

// Ustawienie adresu bazowego dla Master (0-7)
void set_base_address(volatile struct register_info *regs, uint32_t base_address, int master_index) {
    switch (master_index) {
        case 0:
            write_register(regs, &regs->OTSAU0, base_address);
            write_register(regs, &regs->OTSAL0, base_address & 0xFFFFFFFF);
            break;
        case 1:
            write_register(regs, &regs->OTSAU1, base_address);
            write_register(regs, &regs->OTSAL1, base_address & 0xFFFFFFFF);
            break;
        default:
            printf("Nieobsługiwany indeks master: %d\n", master_index);
            break;
    }
}

// Odczytanie adresu bazowego dla Master (0-7)
uint32_t get_base_address(volatile struct register_info *regs, int master_index) {
    switch (master_index) {
        case 0:
            return read_register(regs, &regs->OTSAU0);
        case 1:
            return read_register(regs, &regs->OTSAU1);
        default:
            printf("Nieobsługiwany indeks master: %d\n", master_index);
            return 0;
    }
}

// Ustawienie parametrów Master
void set_master_parameters(volatile struct register_info *regs, uint32_t param_value, int master_index) {
    switch (master_index) {
        case 0:
            write_register(regs, &regs->OTBS0, param_value);
            write_register(regs, &regs->OTAT0, param_value);
            break;
        case 1:
            write_register(regs, &regs->OTBS1, param_value);
            write_register(regs, &regs->OTAT1, param_value);
            break;
        default:
            printf("Nieobsługiwany indeks master: %d\n", master_index);
            break;
    }
}

// Odczytanie parametrów Master
uint32_t get_master_parameters(volatile struct register_info *regs, int master_index) {
    switch (master_index) {
        case 0:
            return read_register(regs, &regs->OTBS0);
        case 1:
            return read_register(regs, &regs->OTBS1);
        default:
            printf("Nieobsługiwany indeks master: %d\n", master_index);
            return 0;
    }
}

// Konwersja wartości do Big Endian
uint32_t to_big_endian(uint32_t val) {
    return ((val >> 24) & 0x000000FF) | ((val >> 8) & 0x0000FF00) | ((val << 8) & 0x00FF0000) | ((val << 24) & 0xFF000000);
}